pub type PeerAddr = SocketAddr;Expand description
The address of a remote peer the client exchanges data with through the relay.
Aliased Type
pub enum PeerAddr {
V4(SocketAddrV4),
V6(SocketAddrV6),
}pub type PeerAddr = SocketAddr;The address of a remote peer the client exchanges data with through the relay.
pub enum PeerAddr {
V4(SocketAddrV4),
V6(SocketAddrV6),
}